// TI File $Revision: /main/9 $
// Checkin $Date: April 21, 2008   15:41:13 $
//###########################################################################
// Filename: Example_28xEcan_A_to_B_Xmit.c
//
// Description: eCAN-A To eCAN-B TXLOOP - Transmit loop
//
// ASSUMPTIONS:
//
//    This program requires the DSP2833x header files.
//
//    Both CAN ports of the 2833x DSP need to be connected
//    to each other (via CAN transceivers)
//
//       eCANA is on GPIO31 (CANTXA)  and
//                   GPIO30 (CANRXA)
//
//       eCANB is on GPIO8  (CANTXB)  and
//                   GPIO10 (CANRXB)
//
//    As supplied, this project is configured for "boot to SARAM"
//    operation.  The 2833x Boot Mode table is shown below.
//    For information on configuring the boot mode of an eZdsp,
//    please refer to the documentation included with the eZdsp,
//
//       $Boot_Table:
//
//         GPIO87   GPIO86     GPIO85   GPIO84
//          XA15     XA14       XA13     XA12
//           PU       PU         PU       PU
//        ==========================================
//            1        1          1        1    Jump to Flash
//            1        1          1        0    SCI-A boot
//            1        1          0        1    SPI-A boot
//            1        1          0        0    I2C-A boot
//            1        0          1        1    eCAN-A boot
//            1        0          1        0    McBSP-A boot
//            1        0          0        1    Jump to XINTF x16
//            1        0          0        0    Jump to XINTF x32
//            0        1          1        1    Jump to OTP
//            0        1          1        0    Parallel GPIO I/O boot
//            0        1          0        1    Parallel XINTF boot
//            0        1          0        0    Jump to SARAM	    <- "boot to SARAM"
//            0        0          1        1    Branch to check boot mode
//            0        0          1        0    Boot to flash, bypass ADC cal
//            0        0          0        1    Boot to SARAM, bypass ADC cal
//            0        0          0        0    Boot to SCI-A, bypass ADC cal
//                                              Boot_Table_End$
//
// DESCRIPTION:
//
//    This example TRANSMITS data to another CAN module using MAILBOX5
//    This program could either loop forever or transmit "n" # of times,
//    where "n" is the TXCOUNT value.
//
//    This example can be used to check CAN-A and CAN-B. Since CAN-B is
//    initialized in DSP2833x_ECan.c, it will acknowledge all frames
//    transmitted by the node on which this code runs. Both CAN ports of
//    the 2833x DSP need to be connected to each other (via CAN transceivers)
//
//###########################################################################
// Original Author: HJ
//
// $TI Release: DSP2833x/DSP2823x C/C++ Header Files V1.31 $
// $Release Date: August 4, 2009 $
//###########################################################################

#include "DSP28x_Project.h"     // Device Headerfile and Examples Include File

#define TXCOUNT  100  // Transmission will take place (TXCOUNT) times..

typedef Uint16  BYTE ;
typedef Uint16  WORD ;
typedef Uint32  DWORD ;  

// Globals for this example
long      i;
long 	  loopcount = 0;
int       test;



#define MK_WORD(Lo, Hi)  (((WORD)(((BYTE)((DWORD)(Lo)  & 0xff))   | (((WORD)((BYTE)((DWORD)(Hi)  & 0xff)))   << 8))))


void CAN_A_PROCESS();//BAI,7-30
void CAN_B_PROCESS();
void delay(int n);
interrupt void ECAN_A_isr(void);
interrupt void ECAN_B_isr(void);

void INT28335_process();



void main()
{
   
/* Create a shadow register structure for the CAN control registers. This is
 needed, since, only 32-bit access is allowed to these registers. 16-bit access
 to these registers could potentially corrupt the register contents. This is
 especially true while writing to a bit (or group of bits) among bits 16 - 31 */
  Uint16 uiTmp1;
  Uint16 uiTmp2;
	Uint16 uiTmp;

// Step 1. Initialize System Control:
// PLL, WatchDog, enable Peripheral Clocks
// This example function is found in the DSP2833x_SysCtrl.c file.
   InitSysCtrl();

// Step 2. Initalize GPIO:
// This example function is found in the DSP2833x_Gpio.c file and
// illustrates how to set the GPIO to it's default state.
// InitGpio();  // Skipped for this example

   // Just initalize eCAN pins for this example
   // This function is in DSP2833x_ECan.c
   InitECanGpio();

// Step 3. Clear all interrupts and initialize PIE vector table:
// Disable CPU interrupts
   DINT;

  // InitPieCtrl();

// Disable CPU interrupts and clear all CPU interrupt flags:
  // IER = 0x0000;
 //  IFR = 0x0000;

  // InitPieVectTable();



	  /*жͨ*/
	     EALLOW;  // This is needed to write to EALLOW protected registers
        // PieVectTable.TINT0 = &cpu_timer0_isr;
         EDIS;    // This is needed to disable write to EALLOW protected registers


      // Enable CPU and PIE interrupts
      // This example function is found in the DSP2833x_PieCtrl.c file.
     






   InitECan();

   INT28335_process();

   test=1;

// Step 5. User specific code:
   for(;;)
   {
   		CAN_B_PROCESS();
		delay(1000);
      	
        uiTmp1 = ECanaMboxes.MBOX0.MDL.word.LOW_WORD;//*CANMBX0A;
        uiTmp2 = ECanaMboxes.MBOX0.MDL.word.HI_WORD;//*CANMBX0B;
        uiTmp = MK_WORD(uiTmp1, uiTmp2);
        if(0x1234 == uiTmp)
        {
      	test=0;
	//	break;
        }

		
		test=1;
   }

   

}



void CAN_A_PROCESS()
{
   ECanaRegs.CANME.bit.ME5=0;//*CANMDER&=~(1<<5);disable mail5
   //ECanaRegs.CANMC.bit.MBNR= 5;
   ECanaRegs.CANMC.bit.CDR = 1 ;
   ECanaMboxes.MBOX5.MDL.word.LOW_WORD=0x34;
   ECanaMboxes.MBOX5.MDL.word.HI_WORD=0x12;
   //ECanaRegs.CANMC.bit.MBNR= 5;
   ECanaRegs.CANMC.bit.CDR =0;
   ECanaRegs.CANME.bit.ME5=1;//*CANMDER|=(1<<5);
   ECanaRegs.CANTRS.bit.TRS5=1;//*CANTCR|=(1<<7); λĴ   

}

void CAN_B_PROCESS()
{
   ECanbRegs.CANME.bit.ME5=0;//*CANMDER&=~(1<<5);disable mail5
   //ECanaRegs.CANMC.bit.MBNR= 5;
   ECanbRegs.CANMC.bit.CDR = 1 ;
   ECanbMboxes.MBOX5.MDL.word.LOW_WORD=0x34;
   ECanbMboxes.MBOX5.MDL.word.HI_WORD=0x12;
   //ECanaRegs.CANMC.bit.MBNR= 5;
   ECanbRegs.CANMC.bit.CDR =0;
   ECanbRegs.CANME.bit.ME5=1;//*CANMDER|=(1<<5);
   ECanbRegs.CANTRS.bit.TRS5=1;//*CANTCR|=(1<<7); λĴ   

}

void delay(int n)
{
    int i;
	for(i=0;i<n;i++) asm("nop");
}




interrupt void ECAN_A_isr(void)
{
  Uint16 uiTmp;
  Uint16 uiTmp1;
  Uint16 uiTmp2;
  ECanaRegs.CANRMP.bit.RMP0 = 1;  //жϽձ־
  uiTmp1 = ECanaMboxes.MBOX0.MDL.word.LOW_WORD;//*CANMBX0A;
  uiTmp2 = ECanaMboxes.MBOX0.MDL.word.HI_WORD;//*CANMBX0B;
  uiTmp = MK_WORD(uiTmp1, uiTmp2);
  if(0x1234 == uiTmp)
  {
	test=0;
  }
  PieCtrlRegs.PIEACK.all = PIEACK_GROUP9;
  EINT;
}


interrupt void ECAN_B_isr(void)
{
  Uint16 uiTmp;
  Uint16 uiTmp1;
  Uint16 uiTmp2;
  ECanbRegs.CANRMP.bit.RMP0 = 1;  //жϽձ־
  uiTmp1 = ECanbMboxes.MBOX0.MDL.word.LOW_WORD;//*CANMBX0A;
  uiTmp2 = ECanbMboxes.MBOX0.MDL.word.HI_WORD;//*CANMBX0B;
  uiTmp = MK_WORD(uiTmp1, uiTmp2);
  if(0x1234 == uiTmp)
  {
	test=0;
  }
  PieCtrlRegs.PIEACK.all = PIEACK_GROUP9;
  EINT;
}


void INT28335_process()
{
   InitPieCtrl();

// Disable CPU interrupts and clear all CPU interrupt flags:
   IER = 0x0000;
   IFR = 0x0000;
   InitPieVectTable();   
  
   
   EALLOW;  // This is needed to write to EALLOW protected registers
   //PieVectTable.TINT2 = &cpu_timer2_isr;
  // PieVectTable.TINT0 = &cpu_timer0_isr;
   PieVectTable.ECAN0INTA = &ECAN_A_isr;//_baijj жϷӳ   ڵַ
   EPwm1Regs.TZEINT.bit.OST=1;  //  Trip Zone Enable Interrupt Register
  // PieVectTable.EPWM1_TZINT = &ZIP1NMI_isr;//_baijj
  // PieVectTable.EPWM1_INT = &cpu_timer1_isr;
  // PieVectTable.EPWM2_INT = &ADSTART_isr;
   EDIS;
   
   IER |= M_INT1;
	// Enable TINT0 in the PIE: Group 1 interrupt 7
   PieCtrlRegs.PIEIER1.bit.INTx7 = 1;

   
   IER |= M_INT9;   // INT 9---CANж   SCI ж
	// Enable TINT0 in the PIE: Group 1 interrupt 7
   PieCtrlRegs.PIEIER9.bit.INTx5 = 1;

    
   IER |= M_INT2;  
   // Enable EPWM INTn in the PIE: Group 2 interrupt 1-2
   PieCtrlRegs.PIEIER2.bit.INTx1 = 1;
   IER |= M_INT3;
   PieCtrlRegs.PIEIER3.bit.INTx1 = 1;
   PieCtrlRegs.PIEIER3.bit.INTx2 = 1;
   
   /********T2C**********************************************/
   //EALLOW;	// This is needed to write to EALLOW protected registers
   //PieVectTable.I2CINT1A = &i2c_int1a_isr;
   //EDIS;   // This is needed to disable write to EALLOW protected registers
// Enable I2C interrupt 1 in the PIE: Group 8 interrupt 1
  // PieCtrlRegs.PIEIER8.bit.INTx1 = 1;
// Enable CPU INT8 which is connected to PIE group 8
   //IER |= M_INT8;
   /******I2C****************************************************/
   EnableInterrupts();
   //EALLOW;
    // SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 1;
   //EDIS;
}
